
# Slot: desc


File description.

URI: [https://w3id.org/neat/fileResource__desc](https://w3id.org/neat/fileResource__desc)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [FileResource](FileResource.md)
